<?php

declare(strict_types=1);

namespace Admin;

use Nette\Security\Authorizator;
use Nette\Security\IAuthenticator;
use Nette\Security\IUserStorage;

class Administrator extends \Nette\Security\User
{
	private ?string $defaultLink = null;

	private ?string $fallbackLink = null;
	
	public function __construct(?IAuthenticator $authenticator = null, ?Authorizator $authorizator = null, ?IUserStorage $legacyStorage = null)
	{
		parent::__construct(clone $legacyStorage, $authenticator, $authorizator);
		
		/** @var \Nette\Http\UserStorage $legacyStorage */
		$legacyStorage = $this->getStorage();
		$legacyStorage->setNamespace('admin');
	}
	
	public function setDefaultLink(string $defaultLink): void
	{
		$this->defaultLink = $defaultLink;
	}

	public function setFallbackLink(string $fallbackLink): void
	{
		$this->fallbackLink = $fallbackLink;
	}

	public function getFallbackLink(): ?string
	{
		return $this->fallbackLink;
	}
	
	public function getDefaultLink(): string
	{
		if (!$this->defaultLink) {
			throw new \DomainException('Default link is not set');
		}
		
		if (!$this->isAllowed($this->defaultLink)) {
			return $this->fallbackLink;
		}
		
		return $this->defaultLink;
	}
}
